@@ -1,6 +1,6 @@
 package App::ansiecho;
 
-our $VERSION = "1.09";
+our $VERSION = "1.10";
 
 use v5.14;
 use warnings;
@@ -61,7 +61,7 @@ use Getopt::EX::Hashed; {
 sub run {
     my $app = shift;
     $app->options(@_);
-    print join($app->separate, $app->retrieve), $app->terminate;
+    print $app->retrieve, $app->terminate;
 }
 
 sub options {
@@ -77,9 +77,15 @@ sub options {
 
 use Term::ANSIColor::Concise qw(ansi_color ansi_code);
 
+sub uniname {
+    local $_ = @_ ? shift : $_;
+    my @names = map { /^[\da-f]{1,6}$/i ? "\\N{U+$_}" : "\\N{$_}" } /[-+_\w ]+/g;
+    unescape join '', @names;
+}
+
 sub retrieve {
     my $app = shift;
-    my $count = shift;
+    my $count = shift // 0;
     my $in = $app->params;
     my(@style, @effect);
 
@@ -87,12 +93,23 @@ sub retrieve {
     my @pending;
     my $charge = sub { push @pending, @_ };
     my $discharge = sub {
-	push @out, join '', splice(@pending), @_ if @pending or @_;
+	return if @pending == 0 and @_ == 0;
+	if ($count == 0 and @out > 0 and $app->separate ne '') {
+	    push @out, $app->separate;
+	}
+	push @out, join '', splice(@pending), @_;
     };
 
     while (@$in) {
 	my $arg = shift @$in;
 
+	# -x : set separator
+	if ($arg =~ /^-x(?<uni>u)?$/) {
+	    my $uni = %+;
+	    my $sep = $app->retrieve(1) // die "Not enough argument.\n";
+	    $app->separate = $uni ? uniname($sep) : $sep;
+	    next;
+	}
 	# -S
 	if ($arg =~ /^-S$/) {
 	    unshift @style, [ \&ansi_code ];
@@ -101,16 +118,21 @@ sub retrieve {
 	# -c, -C
 	if ($arg =~ /^-([cC])(.+)?$/) {
 	    my $target = $1 eq 'c' ? \@effect : \@style;
-	    my($color) = defined $2 ? unescape($2) : $app->retrieve(1);
+	    my $color = defined $2 ? unescape($2) : $app->retrieve(1);
 	    unshift @$target, [ \&ansi_color, $color ];
 	    next;
 	}
 	# -F
 	if ($arg =~ /^-(F)(.+)?$/) {
-	    my($format) = defined $2 ? unescape($2) : $app->retrieve(1);
+	    my $format = defined $2 ? unescape($2) : $app->retrieve(1);
 	    unshift @style, [ \&ansi_sprintf, $format ];
 	    next;
 	}
+	# -U
+	if ($arg =~ /^-(U)$/) {
+	    unshift @style, [ \&uniname ];
+	    next;
+	}
 	# -E
 	if ($arg =~ /^-E$/) {
 	    @style = ();
@@ -165,6 +187,14 @@ sub retrieve {
 	    $arg = ansi_sprintf($format, $app->retrieve($n));
 	}
 	#
+	# -u : Unicode Name
+	#
+	if ($arg =~ /^-u(.+)?$/) {
+	    my $opt = $1;
+	    my $name = $2 // shift(@$in) // die "Not enough argument.\n";
+	    $arg = uniname($name);
+	}
+	#
 	# normal string argument
 	#
 	else {
@@ -191,7 +221,7 @@ sub retrieve {
     }
     $discharge->();
     die "Not enough argument.\n" if $count and @out < $count;
-    return @out;
+    wantarray ? @out : $out[0];
 }
 
 1;
